@@ -80,10 +80,10 @@ pub use ffi::{
 
 #[doc(inline)]
 pub use ffi::{
+    // functions
     ncblit_bgrx,
     ncblit_rgb_loose,
     ncblit_rgb_packed,
-    // functions
     ncblit_rgba,
 };
 
@@ -324,10 +324,12 @@ pub use ffi::{
 // ncplane_set_fchannel,
 //
 // // constants
+// NCPLANE_OPTION_AUTOGROW,
 // NCPLANE_OPTION_FIXED,
 // NCPLANE_OPTION_HORALIGNED,
 // NCPLANE_OPTION_MARGINALIZED,
 // NCPLANE_OPTION_VERALIGNED,
+// NCPLANE_OPTION_VSCROLL,
 //
 // // type alias
 // ncdirectv,
@@ -346,6 +348,7 @@ pub use ffi::{
     ncplane_at_cursor_cell,
     ncplane_at_yx,
     ncplane_at_yx_cell,
+    ncplane_autogrow_p,
     ncplane_base,
     ncplane_below,
     ncplane_box,
@@ -405,6 +408,7 @@ pub use ffi::{
     ncplane_scrolling_p,
     ncplane_scrollup,
     ncplane_scrollup_child,
+    ncplane_set_autogrow,
     ncplane_set_base,
     ncplane_set_base_cell,
     ncplane_set_bg_alpha,
@@ -661,15 +665,18 @@ pub use ffi::{
 pub use ffi::{
     // structs
     nctree,
+    nctree_item,
+    nctree_options,
+
     // functions
+    nctree_add,
     nctree_create,
+    nctree_del,
     nctree_destroy,
     nctree_focused,
     nctree_goto,
-    nctree_item,
     nctree_next,
     nctree_offer_input,
-    nctree_options,
     nctree_plane,
     nctree_prev,
     nctree_redraw,
@@ -750,6 +757,8 @@ pub use ffi::{
     notcurses_cursor_enable,
     notcurses_cursor_yx,
     notcurses_debug,
+    notcurses_default_background,
+    notcurses_default_foreground,
     notcurses_detected_terminal,
     notcurses_drop_planes,
     notcurses_enter_alternate_screen,
@@ -778,7 +787,7 @@ pub use ffi::{
     notcurses_str_blitter,
     notcurses_str_scalemode,
     notcurses_supported_styles,
-    notcurses_ucs32_to_utf8,
+    // notcurses_ucs32_to_utf8,
     notcurses_version,
     notcurses_version_components,
 };
