@@ -5,9 +5,9 @@
 use libc::strcmp;
 
 use crate::{
-    c_api::{self, ffi, nccell_release},
-    cstring, rstring, NcAlpha, NcAlphaApi, NcCell, NcChannel, NcChannels, NcChannelsApi,
-    NcComponent, NcIntResult, NcIntResultApi, NcPaletteIndex, NcPlane, NcRgb, NcStyle, NcStyleApi,
+    c_api::{self, nccell_release},
+    cstring, rstring, NcAlpha, NcCell, NcChannel, NcChannels, NcComponent, NcIntResult,
+    NcIntResultApi, NcPaletteIndex, NcPlane, NcRgb, NcStyle, NcStyleApi,
 };
 
 const NCBOXLIGHT: &str = "┌┐└┘─│";
@@ -234,13 +234,8 @@ pub const fn nccell_bg_palindex(cell: &NcCell) -> NcPaletteIndex {
 ///
 /// *Method: NcCell.[set_fg_palindex()][NcCell#method.set_fg_palindex].*
 #[inline]
-#[allow(clippy::unnecessary_cast)]
 pub fn nccell_set_fg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
-    cell.channels |= NcChannels::FG_DEFAULT_MASK;
-    cell.channels |= NcChannels::FG_PALETTE_MASK;
-    nccell_set_fg_alpha(cell, NcAlpha::OPAQUE);
-    cell.channels &= 0xff000000ffffffff as NcChannels;
-    cell.channels |= (index as NcChannels) << 32;
+    c_api::ncchannels_set_fg_palindex(&mut cell.channels, index)
 }
 
 /// Sets an [`NcCell`]'s background [`NcPaletteIndex`].
@@ -254,11 +249,7 @@ pub fn nccell_set_fg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
 /// *Method: NcCell.[set_bg_palindex()][NcCell#method.set_bg_palindex].*
 #[inline]
 pub fn nccell_set_bg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
-    cell.channels |= NcChannels::BG_DEFAULT_MASK as NcChannels;
-    cell.channels |= NcChannels::BG_PALETTE_MASK as NcChannels;
-    nccell_set_bg_alpha(cell, NcAlpha::OPAQUE);
-    cell.channels &= 0xffffffffff000000;
-    cell.channels |= index as NcChannels;
+    c_api::ncchannels_set_bg_palindex(&mut cell.channels, index)
 }
 
 // Styles ----------------------------------------------------------------------
@@ -311,11 +302,6 @@ pub const fn nccell_cols(cell: &NcCell) -> u8 {
     }
 }
 
-#[deprecated]
-pub fn nccell_width(plane: &NcPlane, cell: &NcCell) -> NcIntResult {
-    unsafe { ffi::nccell_width(plane, cell) }
-}
-
 /// Does the [`NcCell`] contain an East Asian Wide codepoint?
 ///
 /// *Method: NcCell.[double_wide_p()][NcCell#method.double_wide_p].*
@@ -500,7 +486,7 @@ pub fn nccells_load_box(
     NcIntResult::ERR
 }
 
-/// [nccells_load_box] with ASCII characters.
+/// [`nccells_load_box`] with ASCII characters.
 ///
 /// *Method: NcCell.[ascii_box()][NcCell#method.ascii_box].*
 #[inline]
@@ -518,7 +504,25 @@ pub fn nccells_ascii_box(
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXASCII)
 }
 
-/// [nccells_load_box] with heavy line box-drawing characters.
+/// [`nccells_load_box`] with double line box-drawing characters.
+///
+/// *Method: NcCell.[double_box()][NcCell#method.double_box].*
+#[inline]
+pub fn nccells_double_box(
+    plane: &mut NcPlane,
+    style: NcStyle,
+    channels: NcChannels,
+    ul: &mut NcCell,
+    ur: &mut NcCell,
+    ll: &mut NcCell,
+    lr: &mut NcCell,
+    hl: &mut NcCell,
+    vl: &mut NcCell,
+) -> NcIntResult {
+    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXDOUBLE)
+}
+
+/// [`nccells_load_box`] with heavy line box-drawing characters.
 ///
 /// *Method: NcCell.[heavy_box()][NcCell#method.heavy_box].*
 #[inline]
@@ -536,7 +540,7 @@ pub fn nccells_heavy_box(
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXHEAVY)
 }
 
-/// [nccells_load_box] with light line box-drawing characters.
+/// [`nccells_load_box`] with light line box-drawing characters.
 ///
 /// *Method: NcCell.[light_box()][NcCell#method.light_box].*
 #[inline]
@@ -553,3 +557,21 @@ pub fn nccells_light_box(
 ) -> NcIntResult {
     nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXLIGHT)
 }
+
+/// [`nccells_load_box`] with round line box-drawing characters.
+///
+/// *Method: NcCell.[rounded_box()][NcCell#method.rounded_box].*
+#[inline]
+pub fn nccells_rounded_box(
+    plane: &mut NcPlane,
+    style: NcStyle,
+    channels: NcChannels,
+    ul: &mut NcCell,
+    ur: &mut NcCell,
+    ll: &mut NcCell,
+    lr: &mut NcCell,
+    hl: &mut NcCell,
+    vl: &mut NcCell,
+) -> NcIntResult {
+    nccells_load_box(plane, style, channels, ul, ur, ll, lr, hl, vl, NCBOXROUND)
+}
