@@ -1,38 +1,47 @@
 //! `ncchannel*_*` reimplemented functions.
 
 use crate::{
-    c_api, NcAlpha, NcAlphaApi, NcChannel, NcChannels, NcComponent, NcPaletteIndex, NcRgb,
+    c_api, NcAlpha, NcChannel, NcChannels, NcComponent, NcIntResult, NcPaletteIndex, NcRgb,
 };
 
 // Alpha -----------------------------------------------------------------------
 
 /// Gets the [`NcAlpha`] from an [`NcChannel`].
 ///
+/// It is not shifted down, and can be directly compared to `NCALPHA_*` values.
+///
 /// *Method: NcChannel.[alpha()][NcChannel#method.alpha]*
 #[inline]
-pub const fn ncchannel_alpha(channel: NcChannel) -> NcAlpha {
-    channel & c_api::NC_BG_ALPHA_MASK
+pub fn ncchannel_alpha(channel: NcChannel) -> NcAlpha {
+    (channel & c_api::NC_BG_ALPHA_MASK).into()
 }
 
 /// Sets the [`NcAlpha`] of an [`NcChannel`].
 ///
+/// Background channels must not be set to `NCALPHA_HIGHCONTRAST`.
+///
+/// It is an error if alpha contains any bits other than `NCALPHA_*`.
+///
 /// *Method: NcChannel.[set_alpha()][NcChannel#method.set_alpha]*
 #[inline]
-pub fn ncchannel_set_alpha(channel: &mut NcChannel, alpha: NcAlpha) {
-    let alpha_clean = alpha & c_api::NC_BG_ALPHA_MASK;
-    *channel = alpha_clean | (*channel & !c_api::NC_BG_ALPHA_MASK);
+pub fn ncchannel_set_alpha(channel: &mut NcChannel, alpha: NcAlpha) -> NcIntResult {
+    let alpha_u32 = c_api::NcAlpha_u32::from(alpha);
 
-    if alpha != NcAlpha::OPAQUE {
-        // indicate that we are *not* using the default background color
+    if (alpha_u32 & !c_api::NC_BG_ALPHA_MASK) != 0 {
+        return c_api::NCRESULT_ERR;
+    }
+    *channel = alpha_u32 | (*channel & !c_api::NC_BG_ALPHA_MASK);
+    if alpha != NcAlpha::Opaque {
         *channel |= c_api::NC_BGDEFAULT_MASK;
     }
+    c_api::NCRESULT_OK
 }
 
 /// Gets the foreground [`NcAlpha`] from an [`NcChannels`], shifted to LSBs.
 ///
 /// *Method: NcChannels.[fg_alpha()][NcChannels#method.fg_alpha]*
 #[inline]
-pub const fn ncchannels_fg_alpha(channels: NcChannels) -> NcAlpha {
+pub fn ncchannels_fg_alpha(channels: NcChannels) -> NcAlpha {
     ncchannel_alpha(ncchannels_fchannel(channels))
 }
 
@@ -40,7 +49,7 @@ pub const fn ncchannels_fg_alpha(channels: NcChannels) -> NcAlpha {
 ///
 /// *Method: NcChannels.[bg_alpha()][NcChannels#method.bg_alpha]*
 #[inline]
-pub const fn ncchannels_bg_alpha(channels: NcChannels) -> NcAlpha {
+pub fn ncchannels_bg_alpha(channels: NcChannels) -> NcAlpha {
     ncchannel_alpha(ncchannels_bchannel(channels))
 }
 
@@ -48,25 +57,29 @@ pub const fn ncchannels_bg_alpha(channels: NcChannels) -> NcAlpha {
 ///
 /// *Method: NcChannels.[set_fg_alpha()][NcChannels#method.set_fg_alpha]*
 #[inline]
-pub fn ncchannels_set_fg_alpha(channels: &mut NcChannels, alpha: NcAlpha) {
+pub fn ncchannels_set_fg_alpha(channels: &mut NcChannels, alpha: NcAlpha) -> NcIntResult {
     let mut channel = ncchannels_fchannel(*channels);
-    ncchannel_set_alpha(&mut channel, alpha);
+    if ncchannel_set_alpha(&mut channel, alpha) < 0 {
+        return c_api::NCRESULT_ERR;
+    }
     *channels = (channel as NcChannels) << 32 | *channels & 0xffffffff_u64;
+    c_api::NCRESULT_OK
 }
 
 /// Sets the [`NcAlpha`] of the background [`NcChannel`] of an [`NcChannels`].
 ///
 /// *Method: NcChannels.[set_bg_alpha()][NcChannels#method.set_bg_alpha]*
 #[inline]
-pub fn ncchannels_set_bg_alpha(channels: &mut NcChannels, alpha: NcAlpha) {
-    let mut alpha_clean = alpha;
-    if alpha == NcAlpha::HIGHCONTRAST {
-        // forbidden for background alpha, so makes it opaque
-        alpha_clean = NcAlpha::OPAQUE;
+pub fn ncchannels_set_bg_alpha(channels: &mut NcChannels, alpha: NcAlpha) -> NcIntResult {
+    if alpha == NcAlpha::HighContrast {
+        return c_api::NCRESULT_ERR;
     }
     let mut channel = ncchannels_bchannel(*channels);
-    ncchannel_set_alpha(&mut channel, alpha_clean);
+    if ncchannel_set_alpha(&mut channel, alpha) < 0 {
+        return c_api::NCRESULT_ERR;
+    }
     ncchannels_set_bchannel(channels, channel);
+    c_api::NCRESULT_OK
 }
 
 // Channels --------------------------------------------------------------------
@@ -116,20 +129,28 @@ pub fn ncchannels_combine(fchannel: NcChannel, bchannel: NcChannel) -> NcChannel
     channels
 }
 
-/// Returns the `NcChannels` with the color information swapped, but not
-/// alpha, nor other housekeeping bits.
+/// Returns the `NcChannels` with the fore- and background's color information
+/// swapped, but without touching housekeeping bits.
+///
+/// Alpha is retained unless it would lead to an illegal state: `HIGHCONTRAST`,
+/// `TRANSPARENT` and `BLEND` are taken to `OPAQUE` unless the new value is RGB.
 ///
 /// *Method: NcChannels.[reverse()][NcChannels#method.reverse]*
 #[inline]
 pub fn ncchannels_reverse(channels: NcChannels) -> NcChannels {
     let raw = ((ncchannels_bchannel(channels) as NcChannels) << 32)
         + ncchannels_fchannel(channels) as NcChannels;
-    let statemask = c_api::NC_NOBACKGROUND_MASK
-        | (c_api::NC_NOBACKGROUND_MASK >> 32)
-        | (c_api::NC_BG_ALPHA_MASK as NcChannels)
-        | (c_api::NC_NOBACKGROUND_MASK >> 32);
+    let statemask = ((c_api::NC_NOBACKGROUND_MASK | c_api::NC_BG_ALPHA_MASK as NcChannels) << 32)
+        | c_api::NC_NOBACKGROUND_MASK
+        | c_api::NC_BG_ALPHA_MASK as NcChannels;
     let mut ret = (raw as NcChannels) & !statemask;
     ret |= channels & statemask;
+    if ncchannels_bg_alpha(ret) != NcAlpha::Opaque && !ncchannels_bg_rgb_p(ret) {
+        ncchannels_set_bg_alpha(&mut ret, NcAlpha::Opaque);
+    }
+    if ncchannels_fg_alpha(ret) != NcAlpha::Opaque && !ncchannels_fg_rgb_p(ret) {
+        ncchannels_set_fg_alpha(&mut ret, NcAlpha::Opaque);
+    }
     ret
 }
 
@@ -137,6 +158,8 @@ pub fn ncchannels_reverse(channels: NcChannels) -> NcChannels {
 
 /// Gets the red [`NcComponent`] from an [`NcChannel`].
 ///
+/// Only valid if `ncchannel_rgb_p` would return true for the channel.
+///
 /// *Method: NcChannel.[r()][NcChannel#method.r]*
 #[inline]
 pub const fn ncchannel_r(channel: NcChannel) -> NcComponent {
@@ -145,6 +168,8 @@ pub const fn ncchannel_r(channel: NcChannel) -> NcComponent {
 
 /// Gets the green [`NcComponent`] from an [`NcChannel`].
 ///
+/// Only valid if `ncchannel_rgb_p` would return true for the channel.
+///
 /// *Method: NcChannel.[g()][NcChannel#method.g]*
 #[inline]
 pub const fn ncchannel_g(channel: NcChannel) -> NcComponent {
@@ -153,6 +178,8 @@ pub const fn ncchannel_g(channel: NcChannel) -> NcComponent {
 
 /// Gets the blue [`NcComponent`] from an [`NcChannel`].
 ///
+/// Only valid if `ncchannel_rgb_p` would return true for the channel.
+///
 /// *Method: NcChannel.[b()][NcChannel#method.b]*
 #[inline]
 pub const fn ncchannel_b(channel: NcChannel) -> NcComponent {
@@ -194,6 +221,8 @@ pub fn ncchannel_set_b(channel: &mut NcChannel, b: NcComponent) -> NcChannel {
 
 /// Gets the three RGB [`NcComponent`]s from an [`NcChannel`], and returns it.
 ///
+/// Only valid if `ncchannel_rgb_p` would return true for the channel.
+///
 /// *Method: NcChannel.[rgb8()][NcChannel#method.rgb8]*
 #[inline]
 pub fn ncchannel_rgb8(
@@ -211,6 +240,8 @@ pub fn ncchannel_rgb8(
 /// Sets the three RGB [`NcComponent`]s an [`NcChannel`], and marks it as NOT using the
 /// "default color", retaining the other bits unchanged.
 ///
+/// Note: Unlike the original C function, this one can't fail.
+///
 /// *Method: NcChannel.[set_rgb8()][NcChannel#method.set_rgb8]*
 #[inline]
 pub fn ncchannel_set_rgb8(channel: &mut NcChannel, r: NcComponent, g: NcComponent, b: NcComponent) {
@@ -251,7 +282,7 @@ pub fn ncchannels_bg_rgb8(
 /// Sets the three foreground RGB [`NcComponent`]s of an [`NcChannels`], and
 /// marks it as NOT using the "default color", retaining the other bits unchanged.
 ///
-/// NOTE: Unlike the original C function, this one returns the new `NcChannels`.
+/// Note: Unlike the original C function, this one returns the new `NcChannels`.
 ///
 /// *Method: NcChannels.[set_fg_rgb8()][NcChannels#method.set_fg_rgb8]*
 #[inline]
@@ -270,7 +301,7 @@ pub fn ncchannels_set_fg_rgb8(
 /// Sets the three background RGB [`NcComponent`]s of an [`NcChannels`], and
 /// marks it as NOT using the "default color", retaining the other bits unchanged.
 ///
-/// NOTE: Unlike the original C function, this one returns the new `NcChannels`.
+/// Note: Unlike the original C function, this one returns the new `NcChannels`.
 ///
 /// *Method: NcChannels.[set_bg_rgb8()][NcChannels#method.set_bg_rgb8]*
 #[inline]
@@ -292,7 +323,7 @@ pub fn ncchannels_set_bg_rgb8(
 ///
 /// *Method: NcChannels.[fg_rgb()][NcChannels#method.fg_rgb]*
 #[inline]
-pub fn ncchannels_fg_rgb(channels: NcChannels) -> NcRgb {
+pub const fn ncchannels_fg_rgb(channels: NcChannels) -> NcRgb {
     ncchannels_fchannel(channels) & c_api::NC_BG_RGB_MASK
 }
 
@@ -300,10 +331,26 @@ pub fn ncchannels_fg_rgb(channels: NcChannels) -> NcRgb {
 ///
 /// *Method: NcChannels.[bg_rgb()][NcChannels#method.bg_rgb]*
 #[inline]
-pub fn ncchannels_bg_rgb(channels: NcChannels) -> NcRgb {
+pub const fn ncchannels_bg_rgb(channels: NcChannels) -> NcRgb {
     ncchannels_bchannel(channels) & c_api::NC_BG_RGB_MASK
 }
 
+/// Returns true if the foreground channel is set to RGB color.
+///
+/// *Method: NcChannels.[fg_rgb_p()][NcChannels#method.fg_rgb_p]*
+#[inline]
+pub const fn ncchannels_fg_rgb_p(channels: NcChannels) -> bool {
+    ncchannel_rgb_p(ncchannels_fchannel(channels))
+}
+
+/// Returns true if the background channel is set to RGB color.
+///
+/// *Method: NcChannels.[bg_rgb_p()][NcChannels#method.bg_rgb_p]*
+#[inline]
+pub const fn ncchannels_bg_rgb_p(channels: NcChannels) -> bool {
+    ncchannel_rgb_p(ncchannels_bchannel(channels))
+}
+
 /// Gets the [`NcRgb`] of an [`NcChannel`].
 ///
 /// This function basically removes the 4th byte of the NcChannel.
@@ -316,9 +363,20 @@ pub const fn ncchannel_rgb(channel: NcChannel) -> NcRgb {
     channel & c_api::NC_BG_RGB_MASK
 }
 
+/// Returns true if this `NcChannel` is using RGB color.
+///
+/// *Method: NcChannel.[rgb_p()][NcChannel#method.rgb_p]*
+#[inline]
+pub const fn ncchannel_rgb_p(channel: NcChannel) -> bool {
+    // bitwise or is intentional (allows compiler more freedom)
+    !(ncchannel_default_p(channel) | ncchannel_palindex_p(channel))
+}
+
 /// Sets the [`NcRgb`] of an [`NcChannel`], and marks it as NOT using the
 /// "default color", retaining the other bits unchanged.
 ///
+/// Note: Unlike the original C function, this one can't fail.
+///
 /// *Method: NcChannel.[set()][NcChannel#method.set]*
 #[inline]
 pub fn ncchannel_set(channel: &mut NcChannel, rgb: NcRgb) {
@@ -359,12 +417,13 @@ pub const fn ncchannel_default_p(channel: NcChannel) -> bool {
     (channel & c_api::NC_BGDEFAULT_MASK) == 0
 }
 
-/// Marks an [`NcChannel`] as using its "default color", which also marks it opaque.
+/// Marks an [`NcChannel`] as using its "default color". Sets alpha as `OPAQUE`.
 ///
 /// *Method: NcChannel.[set_default()][NcChannel#method.set_default]*
 #[inline]
 pub fn ncchannel_set_default(channel: &mut NcChannel) -> NcChannel {
-    *channel &= !(c_api::NC_BGDEFAULT_MASK | NcAlpha::HIGHCONTRAST);
+    *channel &= !c_api::NC_BGDEFAULT_MASK; // turn off not-default bit
+    ncchannel_set_alpha(channel, NcAlpha::Opaque);
     *channel
 }
 
@@ -384,7 +443,7 @@ pub fn ncchannel_set_not_default(channel: &mut NcChannel) -> NcChannel {
 ///
 /// *Method: NcChannels.[fg_default_p()][NcChannels#method.fg_default_p]*
 #[inline]
-pub fn ncchannels_fg_default_p(channels: NcChannels) -> bool {
+pub const fn ncchannels_fg_default_p(channels: NcChannels) -> bool {
     ncchannel_default_p(ncchannels_fchannel(channels))
 }
 
@@ -395,7 +454,7 @@ pub fn ncchannels_fg_default_p(channels: NcChannels) -> bool {
 ///
 /// *Method: NcChannels.[bg_default_p()][NcChannels#method.bg_default_p]*
 #[inline]
-pub fn ncchannels_bg_default_p(channels: NcChannels) -> bool {
+pub const fn ncchannels_bg_default_p(channels: NcChannels) -> bool {
     ncchannel_default_p(ncchannels_bchannel(channels))
 }
 
@@ -492,18 +551,16 @@ pub const fn ncchannel_palindex(channel: NcChannel) -> NcPaletteIndex {
 ///
 /// *Method: NcChannel.[set_palindex()][NcChannel#method.set_palindex]*
 pub fn ncchannel_set_palindex(channel: &mut NcChannel, index: NcPaletteIndex) {
-    *channel |= c_api::NC_BGDEFAULT_MASK;
-    *channel |= c_api::NC_BG_PALETTE;
-    ncchannel_set_alpha(channel, c_api::NCALPHA_OPAQUE);
+    ncchannel_set_alpha(channel, NcAlpha::Opaque);
     *channel &= 0xFF000000;
-    *channel |= index as NcChannel;
+    *channel |= c_api::NC_BGDEFAULT_MASK | c_api::NC_BG_PALETTE | index as NcChannel;
 }
 
 /// Is this [`NcChannel`] using palette-indexed color rather than RGB?
 ///
 /// *Method: NcChannel.[palindex_p()][NcChannel#method.palindex_p]*
 #[inline]
-pub fn ncchannel_palindex_p(channel: NcChannel) -> bool {
+pub const fn ncchannel_palindex_p(channel: NcChannel) -> bool {
     !(ncchannel_default_p(channel) && (channel & c_api::NC_BG_PALETTE) == 0)
 }
 
@@ -511,7 +568,7 @@ pub fn ncchannel_palindex_p(channel: NcChannel) -> bool {
 ///
 /// *Method: NcChannels.[fg_palindex()][NcChannels#method.fg_palindex]*
 #[inline]
-pub fn ncchannels_fg_palindex(channels: NcChannels) -> NcPaletteIndex {
+pub const fn ncchannels_fg_palindex(channels: NcChannels) -> NcPaletteIndex {
     ncchannel_palindex(ncchannels_fchannel(channels))
 }
 
@@ -519,7 +576,7 @@ pub fn ncchannels_fg_palindex(channels: NcChannels) -> NcPaletteIndex {
 ///
 /// *Method: NcChannels.[bg_palindex()][NcChannels#method.bg_palindex]*
 #[inline]
-pub fn ncchannels_bg_palindex(channels: NcChannels) -> NcPaletteIndex {
+pub const fn ncchannels_bg_palindex(channels: NcChannels) -> NcPaletteIndex {
     ncchannel_palindex(ncchannels_bchannel(channels))
 }
 
@@ -528,7 +585,7 @@ pub fn ncchannels_bg_palindex(channels: NcChannels) -> NcPaletteIndex {
 ///
 /// *Method: NcChannels.[fg_palindex_p()][NcChannels#method.fg_palindex_p]*
 #[inline]
-pub fn ncchannels_fg_palindex_p(channels: NcChannels) -> bool {
+pub const fn ncchannels_fg_palindex_p(channels: NcChannels) -> bool {
     ncchannel_palindex_p(ncchannels_fchannel(channels))
 }
 
@@ -537,7 +594,7 @@ pub fn ncchannels_fg_palindex_p(channels: NcChannels) -> bool {
 ///
 /// *Method: NcChannels.[bg_palindex_p()][NcChannels#method.bg_palindex_p]*
 #[inline]
-pub fn ncchannels_bg_palindex_p(channels: NcChannels) -> bool {
+pub const fn ncchannels_bg_palindex_p(channels: NcChannels) -> bool {
     ncchannel_palindex_p(ncchannels_bchannel(channels))
 }
 
