@@ -123,7 +123,7 @@ impl NcPlane {
     pub fn set_fg_alpha(&mut self, alpha: NcAlpha) -> NcResult<()> {
         error![
             unsafe { c_api::ncplane_set_fg_alpha(self, alpha as i32) },
-            &format!("NcPlane.set_fg_alpha({:0X})", alpha)
+            &format!("NcPlane.set_fg_alpha({})", alpha)
         ]
     }
 
@@ -133,7 +133,7 @@ impl NcPlane {
     pub fn set_bg_alpha(&mut self, alpha: NcAlpha) -> NcResult<()> {
         error![
             unsafe { c_api::ncplane_set_bg_alpha(self, alpha as i32) },
-            &format!("NcPlane.set_bg_alpha({:0X})", alpha)
+            &format!("NcPlane.set_bg_alpha({})", alpha)
         ]
     }
 }
@@ -501,7 +501,7 @@ impl NcPlane {
     /// *C style function: [ncplane_set_fg_palindex()][c_api::ncplane_set_fg_palindex].*
     pub fn set_fg_palindex(&mut self, palindex: NcPaletteIndex) {
         unsafe {
-            c_api::ncplane_set_fg_palindex(self, palindex as i32);
+            c_api::ncplane_set_fg_palindex(self, palindex as u32);
         }
     }
 
@@ -513,7 +513,7 @@ impl NcPlane {
     /// *C style function: [ncplane_set_bg_palindex()][c_api::ncplane_set_bg_palindex].*
     pub fn set_bg_palindex(&mut self, palindex: NcPaletteIndex) {
         unsafe {
-            c_api::ncplane_set_bg_palindex(self, palindex as i32);
+            c_api::ncplane_set_bg_palindex(self, palindex as u32);
         }
     }
 }
@@ -950,8 +950,9 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_puttext()][c_api::ncplane_puttext].*
     pub fn puttext(&mut self, y: NcDim, align: NcAlign, string: &str) -> NcResult<NcDim> {
-        let res =
-            unsafe { c_api::ncplane_puttext(self, y as i32, align, cstring![string], null_mut()) };
+        let res = unsafe {
+            c_api::ncplane_puttext(self, y as i32, align.into(), cstring![string], null_mut())
+        };
         error![res, &format!("NcPlane.puttext({:?})", string), res as NcDim]
     }
 
@@ -1169,7 +1170,13 @@ impl NcPlane {
         string: &str,
     ) -> NcResult<NcDim> {
         let res = unsafe {
-            c_api::ncplane_putnstr_aligned(self, y as i32, align, num_bytes, cstring![string])
+            c_api::ncplane_putnstr_aligned(
+                self,
+                y as i32,
+                align.into(),
+                num_bytes,
+                cstring![string],
+            )
         };
         error![
             res,
@@ -1784,8 +1791,7 @@ impl NcPlane {
     /// aligned according to `align` within this plane.
     ///
     /// Returns `-`[NcIntResult::MAX][crate::NcIntResult::MAX] if
-    /// [`NcAlign::UNALIGNED`][NcAlign#associatedconstant.UNALIGNED]
-    /// or invalid [`NcAlign`].
+    /// [`NcAlign::Unaligned`].
     ///
     /// *C style function: [ncplane_halign()][c_api::ncplane_halign].*
     #[inline]
@@ -1802,15 +1808,16 @@ impl NcPlane {
     /// aligned according to `align` within this plane.
     ///
     /// Returns `-`[NcIntResult::MAX][crate::NcIntResult::MAX] if
-    /// [`NcAlign::UNALIGNED`][NcAlign#associatedconstant.UNALIGNED]
-    /// or invalid [`NcAlign`].
+    /// [`NcAlign::Unaligned`].
     ///
     /// *C style function: [ncplane_valign()][c_api::ncplane_valign].*
     #[inline]
-    pub fn valign(&mut self, align: NcAlign, numrows: NcDim) -> NcResult<()> {
+    pub fn valign(&mut self, align: NcAlign, numrows: NcDim) -> NcResult<NcDim> {
+        let res = c_api::ncplane_valign(self, align, numrows);
         error![
-            c_api::ncplane_valign(self, align, numrows),
-            &format!("NcPlane.valign({:?}, {})", align, numrows)
+            res,
+            &format!("NcPlane.valign({:?}, {})", align, numrows),
+            res as NcDim
         ]
     }
 
@@ -1904,7 +1911,7 @@ impl NcPlane {
         let res_array = unsafe {
             c_api::ncplane_as_rgba(
                 self,
-                blitter,
+                blitter.into(),
                 beg_y.unwrap_or(NcDim::MAX) as i32,
                 beg_x.unwrap_or(NcDim::MAX) as i32,
                 len_y.unwrap_or(0),
@@ -2167,6 +2174,8 @@ impl NcPlane {
     }
 
     /// Returns `true` if this `NcPlane` has scrolling enabled, or `false` otherwise.
+    ///
+    /// *C style function: [ncplane_scrolling_p()][c_api::ncplane_scrolling_p].*
     pub fn scrolling_p(&self) -> bool {
         unsafe { c_api::ncplane_scrolling_p(self) }
     }
@@ -2182,9 +2191,12 @@ impl NcPlane {
     /// fail at the eleventh character. In either case, the cursor will be left
     /// at location 0x10; it must be moved before further printing can take place. I
     ///
+    /// See also
+    /// `NcPlaneOptions::`[`VSCROLL`][NcPlaneOptions#associatedconstant.VSCROLL]
+    ///
     /// *C style function: [ncplane_set_scrolling()][c_api::ncplane_set_scrolling].*
     pub fn set_scrolling(&mut self, scroll: bool) -> bool {
-        unsafe { c_api::ncplane_set_scrolling(self, scroll) }
+        unsafe { c_api::ncplane_set_scrolling(self, scroll.into()) }
     }
 
     /// Scrolls down the current plane `r` times.
@@ -2210,6 +2222,37 @@ impl NcPlane {
         let res = unsafe { c_api::ncplane_scrollup_child(self, child) };
         error![res, "", res as NcDim]
     }
+
+    /// Returns `true` if this `NcPlane` has autogrow enabled, or `false` otherwise.
+    ///
+    /// *C style function: [ncplane_autogrow_p()][c_api::ncplane_autogrow_p].*
+    pub fn autogrow_p(&self) -> bool {
+        unsafe { c_api::ncplane_autogrow_p(self) }
+    }
+
+    /// (Un)Sets the automatic growth of the plane to accommodate output.
+    ///
+    /// Returns true if autogrow was previously enabled, or false otherwise.
+    ///
+    /// By default, planes are created with autogrow disabled.
+    ///
+    /// Normally, once output reaches the right boundary of a plane, it is
+    /// impossible to place more output unless the cursor is first moved.
+    ///
+    /// If scrolling is enabled, the cursor will automatically move down and to
+    /// the left in this case, but upon reaching the bottom right corner of the
+    /// plane, it is impossible to place more output without a scrolling event.
+    ///
+    /// If autogrow is in play, the plane will automatically be enlarged to
+    /// accommodate output. If scrolling is disabled, growth takes place to the
+    /// right; it otherwise takes place at the bottom.
+    ///
+    /// The plane only grows in one dimension.
+    ///
+    /// *C style function: [ncplane_set_autogrow()][c_api::ncplane_set_autogrow].*
+    pub fn set_autogrow(&mut self, autogrow: bool) -> bool {
+        unsafe { c_api::ncplane_set_autogrow(self, autogrow.into()) }
+    }
 }
 
 // -----------------------------------------------------------------------------
